//
//  EVCK_GUI.java
//  EVCK
//
//  Created by dario on 15/04/05.
//  Copyright 2005 __MyCompanyName__. All rights reserved.
//

import java.awt.*;
import java.awt.image.*;
import javax.swing.*;

/**
 * A simple Graphic User Interface for the EVCK.
 * Provide frames with the encoding resulting images.
 * Optionally, it can shows the decryotion result.
 */
public class EVCK_GUI {
	
	/**
	 * Constructs the GUI.
	 * @param ims share images array
	 * @param showresult if <code>true</code> shows also a frame with the resulting image.
	 */
	public EVCK_GUI(BufferedImage[] ims, boolean showresult)
	{	//generate the internal frames with the share images
		JInternalFrame f1 = new ImageFrame("Share 1", ims[0]);
		JInternalFrame f2 = new ImageFrame("Share 2", ims[1]);
		
		//generate the main frame that contains alla frames
		EVCK_MainFrame mf = new EVCK_MainFrame();
		mf.show();
		mf.addInternal(f1);
		mf.addInternal(f2);
		//if showresult is setted true show another frame with the images resulting from
		//stacking together images in ims
		if(showresult)
		{	BufferedImage sim = VirtualEye.overlap(ims);
			JInternalFrame secret = new ImageFrame("Secret", sim);
			mf.addInternal(secret);
		}
	}
}

/**
 * The principal frame of the GUI
*/
class EVCK_MainFrame extends JFrame
{
	JDesktopPane dp;
	
	/**
	 * Provides this object construction.
	*/
	public EVCK_MainFrame()
	{	super("Extended Visual Cryptography Kit");
		setSize(600,600);
		//using a JDesktopPane for using internal frames
		dp = new JDesktopPane();
		setContentPane(dp);
		setDefaultCloseOperation(EXIT_ON_CLOSE);
	}
	
	/**
	 * Adds the specified internal frame
	 * @param jif the internal frame to add
	*/
	public void addInternal(JInternalFrame jif)
	{	jif.setVisible(true);
		dp.add(jif);
		try
		{	jif.setSelected(true);
		}catch(java.beans.PropertyVetoException e){}
	}
}

/**
 * A frame containing an image
*/
class ImageFrame extends JInternalFrame
{	private static int id;
	
	/**
	 * Constructs a new frame with the <code>im</code> image and the
	 * <code>title</code> title.
	 * Mantains a counter for positioning the frames without overlap
	 * @param title frames' title
	 * @param im image to show
	*/
	public ImageFrame(String title, BufferedImage im)
	{	super(title, true, true, true, true);
		id = id+1;
		setSize(im.getWidth(), im.getHeight());
		setLocation(id*20,id*20);
		Container contentPane = getContentPane();
		contentPane.add(new ImagePanel(im));
	}
}

/**
 * A panel that draw an image.
*/
class ImagePanel extends JPanel
{	
	BufferedImage img;
	
	public ImagePanel(BufferedImage im)
	{	img = im;
	}
	
	public void paintComponent(Graphics g)
	{	super.paintComponent(g);
		g.drawImage(img,0,0, null);
	}
}